@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: userInfo.php 2017 2009-06-29 02:16:23Z fishbone $
+ * @version    SVN: $Id: userInfo.php 3583 2010-09-11 10:41:20Z fishbone $
  * @link       http://www.magic3.org
  */
 class UserInfo
@@ -25,6 +25,8 @@ class UserInfo
 	const USER_TYPE_NOT_AUTHENTICATED	= -1;				// 未承認ユーザ
 	const USER_TYPE_TMP					= 0;				// 仮ユーザ
 	const USER_TYPE_NORMAL				= 10;				// 一般ユーザ
+	const USER_TYPE_AUTHOR				= 20;				// 投稿ユーザ
+	//const USER_TYPE_EDITOR				= 30;				// 編集ユーザ
 	const USER_TYPE_MANAGER				= 50;				// システム運営者(ウィジェットの管理機能が使用可能)(このレベル以上が管理機能が使用できる)
 	const USER_TYPE_SYS_ADMIN			= 100;				// システム管理者
 	
