@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseFrameContainer.php 3752 2010-10-29 01:43:18Z fishbone $
+ * @version    SVN: $Id: baseFrameContainer.php 3886 2010-12-10 03:59:00Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/db/systemDb.php');		// システムDBアクセスクラス
@@ -159,7 +159,8 @@ class BaseFrameContainer extends Core
 						}
 					} else {		// サイトアクセスできない場合は、管理画面でメッセージを表示
 						if ($cmd == M3_REQUEST_CMD_LOGIN ||					// ログイン画面を表示のとき
-							$cmd == M3_REQUEST_CMD_LOGOUT){				// ログアウトのとき
+							$cmd == M3_REQUEST_CMD_LOGOUT ||				// ログアウトのとき
+							$cmd == M3_REQUEST_CMD_PREVIEW){					// サイトのプレビューを表示
 							$toAdminType = 1;		// ログイン画面へ
 						} else {
 							$toAdminType = 2;		// サイト非公開画面へ
