@@ -9,7 +9,7 @@ defined('M3_SYSTEM') or die('Access error: Direct access denied.');
 <link href="<?php echo $mosConfig_live_site; ?>/templates/_admin/css/style.css" rel="stylesheet" type="text/css" />
 <!--[if IE]><link rel="stylesheet" type="text/css" media="screen" href="<?php echo $mosConfig_live_site;?>/templates/_admin/css/iestyles.css" /><![endif]-->
 </head>
-<body>
+<body<?php mosBodyStyle(); ?>>
 <table width="100%" border="0" cellspacing="0" cellpadding="0">
   <tr><td valign="top"><?php mosLoadModules('top'); ?></td></tr>
 </table>
