@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: access_countWidgetContainer.php 2227 2009-08-15 14:59:41Z fishbone $
+ * @version    SVN: $Id: access_countWidgetContainer.php 3177 2010-06-02 05:22:46Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -20,6 +20,8 @@ class access_countWidgetContainer extends BaseWidgetContainer
 {
 	private $db;			// DB接続オブジェクト
     private $config = array();
+	private $isSystemManageUser;	// システム運用可能ユーザかどうか
+	private $isHiddenCounter;	// システム管理者、システム運用者の場合のみカウンターを表示するかどうか
 	
 	/**
 	 * コンストラクタ
@@ -70,8 +72,22 @@ class access_countWidgetContainer extends BaseWidgetContainer
 	 */
 	function _assign($request, &$param)
 	{
+		$this->isSystemManageUser = $this->gEnv->isSystemManageUser();	// システム運用可能ユーザかどうか
+		
+		// 表示設定取得
+		$this->isHiddenCounter = 0;	// システム管理者、システム運用者の場合のみカウンターを表示するかどうか
+		$paramObj = $this->getWidgetParamObj();
+		if (!empty($paramObj)){
+			$this->isHiddenCounter	= $paramObj->isHiddenCounter;
+		}
+			
 		// 作成したHTMLを出力
-		$this->tmpl->addVar("_widget", "NUMBER_LIST", $this->createOutput());
+		$numberList = $this->createOutput();
+		if (empty($numberList)){		// データが空のときは出力をキャンセル
+			$this->cancelParse();
+		} else {
+			$this->tmpl->addVar("_widget", "number_list", $numberList);
+		}
 	}
 	/**
 	 * 新規アクセスかどうかのチェック
@@ -102,11 +118,14 @@ class access_countWidgetContainer extends BaseWidgetContainer
 		$date = date('Y-m-d');
 		$up = false;		// 新規かどうか
 		
-		// 1セッションに付き、一回だけカウンタを更新する
-		// 新規セッションであれば、カウンタを更新
-		if ($this->isNewVisitor()){
-			$this->db->incrementCount($date);
-			$up = true;
+		// カウンタを更新
+		if (!$this->isSystemManageUser){	// システム管理者、システム運用者の場合はカウントしない
+			// 1セッションに付き、一回だけカウンタを更新する
+			// 新規セッションであれば、カウンタを更新
+			if ($this->isNewVisitor()){
+				$this->db->incrementCount($date);
+				$up = true;
+			}
 		}
 		$count = $this->db->getCount($date);
 		return $count;
@@ -118,30 +137,36 @@ class access_countWidgetContainer extends BaseWidgetContainer
 	 */
     function createOutput()
 	{
+		// カウンター更新
         $count = $this->readCounter($up);
-		$countStr = sprintf("%0"."".$this->config['pad'].""."d", $count -1);	// 1つ前のカウント
-        $destCountStr = sprintf("%0"."".$this->config['pad'].""."d", $count);	// 実際のカウント
-		$html_output = '<table cellpadding="0" cellspacing="0" border="0" width="100%"><tr align="center"><td>' . M3_NL;
-		if ($up){
-			for ($i = 0; $i < strlen($countStr); $i++){
-				if (substr($countStr, $i, 1) == substr($destCountStr, $i, 1)){
-					$digit_pos = substr($countStr, $i, 1);
-					$html_output .= "<img src=\"".$this->config['img']."$digit_pos.gif\"";
-				} else {
-					$digit_pos = substr($destCountStr, $i, 1);
-					$html_output .= "<img src=\"".$this->config['animated_img']. $this->config['animated_img_prefix'] . "$digit_pos.gif\"";
-				}
-				$html_output .= " width=\"".$this->config['width']."\" height=\"".$this->config['height']."\">";
-			}
+		
+		if (!empty($this->isHiddenCounter) && !$this->isSystemManageUser){		// システム管理者、システム運用者以外はカウンターを表示しない
+			return '';
 		} else {
-			for ($i = 0; $i < strlen($countStr); $i++){
-				$digit_pos = substr($destCountStr, $i, 1);
-				$html_output .= "<img src=\"".$this->config['img']."$digit_pos.gif\"";
-				$html_output .= " width=\"".$this->config['width']."\" height=\"".$this->config['height']."\">";
+			$countStr = sprintf("%0"."".$this->config['pad'].""."d", $count -1);	// 1つ前のカウント
+	        $destCountStr = sprintf("%0"."".$this->config['pad'].""."d", $count);	// 実際のカウント
+			$html_output = '<table cellpadding="0" cellspacing="0" border="0" width="100%"><tr align="center"><td>' . M3_NL;
+			if ($up){
+				for ($i = 0; $i < strlen($countStr); $i++){
+					if (substr($countStr, $i, 1) == substr($destCountStr, $i, 1)){
+						$digit_pos = substr($countStr, $i, 1);
+						$html_output .= "<img src=\"".$this->config['img']."$digit_pos.gif\"";
+					} else {
+						$digit_pos = substr($destCountStr, $i, 1);
+						$html_output .= "<img src=\"".$this->config['animated_img']. $this->config['animated_img_prefix'] . "$digit_pos.gif\"";
+					}
+					$html_output .= " width=\"".$this->config['width']."\" height=\"".$this->config['height']."\">";
+				}
+			} else {
+				for ($i = 0; $i < strlen($countStr); $i++){
+					$digit_pos = substr($destCountStr, $i, 1);
+					$html_output .= "<img src=\"".$this->config['img']."$digit_pos.gif\"";
+					$html_output .= " width=\"".$this->config['width']."\" height=\"".$this->config['height']."\">";
+				}
 			}
+			$html_output .= '</td></tr></table>' . M3_NL;
+	        return $html_output;
 		}
-		$html_output .= '</td></tr></table>' . M3_NL;
-        return $html_output;
     }
 }
 ?>
