@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainTopWidgetContainer.php 3822 2010-11-15 01:58:17Z fishbone $
+ * @version    SVN: $Id: admin_mainTopWidgetContainer.php 3887 2010-12-10 04:15:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -139,13 +139,27 @@ class admin_mainTopWidgetContainer extends admin_mainBaseWidgetContainer
 		// トップページ用画像
 		$imageUrl = $this->db->getSystemConfig(self::TOPPAGE_IMAGE_PATH);
 		if (!empty($imageUrl)){
-			$imageUrl = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $imageUrl);
-			$this->tmpl->addVar("showimage", "toppage_img", $imageUrl);
-			$this->tmpl->setAttribute('showimage', 'visibility', 'visible');
+			if (strStartsWith($imageUrl, '/')){		// 相対パス表記のとき
+				$relativePath = $this->gEnv->getRelativePathToSystemRootUrl($this->gEnv->getDocumentRootUrl() . $imageUrl);
+				$imagePath = $this->gEnv->getSystemRootPath() . $relativePath;
+				$imageUrl = $this->gEnv->getRootUrl() . $relativePath;
+			} else {		// マクロ表記のとき
+				$imagePath = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getSystemRootPath(), $imageUrl);
+				$imageUrl = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $imageUrl);
+			}
+			if (file_exists($imagePath)){		// 画像ファイルが存在するとき
+				$this->tmpl->addVar("showimage", "toppage_img", $imageUrl);
+				$this->tmpl->setAttribute('showimage', 'visibility', 'visible');
+			}
 		}
 		
 		// 管理用URL設定
 		$this->tmpl->addVar("_widget", "admin_url", $this->gEnv->getDefaultAdminUrl());
+		
+		// テキストをローカライズ
+		$localeText = array();
+		$localeText['msg_logout'] = $this->_('Logout from system?');		// ログアウトしますか?
+		$this->setLocaleText($localeText);
 	}
 }
 ?>
