@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_dropdown_menuWidgetContainer.php 2251 2009-08-25 06:17:47Z fishbone $
+ * @version    SVN: $Id: admin_dropdown_menuWidgetContainer.php 2572 2009-11-19 01:19:56Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -132,7 +132,7 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 				$newObj->cssId	= $this->cssId;					// CSS用ID
 				$newObj->css	= $this->css;					// メニューCSS
 				
-				$ret = $this->addPageDefParam($defSerial, $defConfigId, $this->paramObj, $newObj);
+				$ret = $this->addPageDefParam($defSerial, $defConfigId, $this->paramObj, $newObj, $this->menuId);
 				if ($ret){
 					$this->setGuidanceMsg('データを追加しました');
 					
@@ -150,16 +150,18 @@ class admin_dropdown_menuWidgetContainer extends BaseAdminWidgetContainer
 				$ret = $this->getPageDefParam($defSerial, $defConfigId, $this->paramObj, $this->configId, $targetObj);
 				if ($ret){
 					// ウィジェットオブジェクト更新
-					$targetObj->menuId	= $this->menuId;		// メニューID
 					$targetObj->showTitle = $showTitle;					// タイトルを表示するかどうか
 					$targetObj->limitUser = $limitUser;					// ユーザを制限するかどうか
 					//$targetObj->menuType = $this->menuType;			// メニュータイプは更新しない
 					$targetObj->cssId	= $this->cssId;					// CSS用ID
 					$targetObj->css		= $this->css;					// メニューCSS
+					
+					// 取得値で更新
+					$this->menuId = $targetObj->menuId;		// メニューID
 				}
 				
 				// 設定値を更新
-				if ($ret) $ret = $this->updatePageDefParam($defSerial, $defConfigId, $this->paramObj, $this->configId, $targetObj);
+				if ($ret) $ret = $this->updatePageDefParam($defSerial, $defConfigId, $this->paramObj, $this->configId, $targetObj, $this->menuId);
 				if ($ret){
 					$this->setMsg(self::MSG_GUIDANCE, 'データを更新しました');
 					$replaceNew = true;			// データ再取得
