@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m_blogReadWidgetContainer.php 3739 2010-10-27 01:22:18Z fishbone $
+ * @version    SVN: $Id: m_blogReadWidgetContainer.php 3836 2010-11-17 06:05:07Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/m_blogBaseWidgetContainer.php');
@@ -67,6 +67,7 @@ class m_blogReadWidgetContainer extends m_blogBaseWidgetContainer
 		$entryViewCount	= $this->_configArray[self::CF_ENTRY_VIEW_COUNT];// 記事表示数
 		if (empty($entryViewCount)) $entryViewCount = self::DEFAULT_VIEW_COUNT;
 		$entryViewOrder	= $this->_configArray[self::CF_ENTRY_VIEW_ORDER];// 記事表示順
+		$titleColor = $this->_configArray[self::CF_TITLE_COLOR];// タイトル背景色
 			
 		// 入力値取得
 		$act = $request->trimValueOf('act');
@@ -80,7 +81,7 @@ class m_blogReadWidgetContainer extends m_blogBaseWidgetContainer
 		$day = $request->trimValueOf('day');		// 日指定
 		//$keyword = $request->trimValueOf('keyword');// 検索キーワード
 		$keyword = $request->mobileTrimValueOf('keyword');// 検索キーワード
-		$category = $request->trimValueOf('category');		// カテゴリー
+		$category = $request->trimValueOf(M3_REQUEST_PARAM_CATEGORY_ID);		// カテゴリID
 
 		$showDefault = false;			// デフォルト状態での表示
 		if ($act == 'search'){			// 検索
@@ -143,13 +144,13 @@ class m_blogReadWidgetContainer extends m_blogBaseWidgetContainer
 				$totalCount = $this->_db->getEntryItemsCountByCategory($now, $category, $this->langId);
 
 				// リンク文字列作成、ページ番号調整
-				$pageLink = $this->createPageLink($pageNo, $totalCount, $entryViewCount, $this->_currentPageUrl . '&act=view&category=' . $category);
+				$pageLink = $this->createPageLink($pageNo, $totalCount, $entryViewCount, $this->_currentPageUrl . '&act=view&' . M3_REQUEST_PARAM_CATEGORY_ID . '=' . $category);
 				
 				// 記事一覧を表示
 				$this->_db->getEntryItemsByCategory($entryViewCount, $pageNo, $now, $category, $this->langId, $entryViewOrder, array($this, 'itemsLoop'));
 
 				// タイトルの設定
-				$ret = $this->categoryDb->getCategoryByCategoryId($category, $this->gEnv->getDefaultLanguage(), $row);
+				$ret = $this->_db->getCategoryByCategoryId($category, $this->gEnv->getDefaultLanguage(), $row);
 				if ($ret) $title = $row['bc_name'];
 				
 				// ブログ記事データがないときはデータなしメッセージ追加
@@ -278,8 +279,13 @@ class m_blogReadWidgetContainer extends m_blogBaseWidgetContainer
 		
 		// タイトルの設定
 		if (!empty($title)){
+			// タイトル作成
+			$titleStr = '<div align="center" style="text-align:center;';
+			if (!empty($titleColor)) $titleStr .= 'background-color:' . $titleColor . ';';// タイトル背景色
+			$titleStr .= '">' . $this->convertToDispString($title) . '</div>';
+
 			$this->tmpl->setAttribute('show_title', 'visibility', 'visible');		// 年月表示
-			$this->tmpl->addVar("show_title", "title", $this->convertToDispString($title));
+			$this->tmpl->addVar("show_title", "title", $titleStr);
 		}
 		
 		// HTMLサブタイトルを設定
