@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: convert_html.php 1176 2008-11-05 04:23:39Z fishbone $
+ * @version    SVN: $Id: convert_html.php 3474 2010-08-13 10:36:48Z fishbone $
  * @link       http://www.magic3.org
  */
 // Copyright (C)
@@ -52,15 +52,15 @@ class Element
 	function Element()
 	{
 		$this->elements = array();
-		$this->last     = & $this;
+		$this->last     = $this;
 	}
 
 	function setParent(& $parent)
 	{
-		$this->parent = & $parent;
+		$this->parent = $parent;
 	}
 
-	function & add(& $obj)
+	function add(& $obj)
 	{
 		if ($this->canContain($obj)) {
 			return $this->insert($obj);
@@ -69,12 +69,12 @@ class Element
 		}
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
 		$obj->setParent($this);
-		$this->elements[] = & $obj;
+		$this->elements[] = $obj;
 
-		return $this->last = & $obj->last;
+		return $this->last = $obj->last;
 	}
 
 	function canContain($obj)
@@ -110,7 +110,7 @@ class Element
 }
 
 // Returns inline-related object
-function & Factory_Inline($text)
+function Factory_Inline($text)
 {
 	// Check the first letter of the line
 	if (substr($text, 0, 1) == '~') {
@@ -120,7 +120,7 @@ function & Factory_Inline($text)
 	}
 }
 
-function & Factory_DList(& $root, $text)
+function Factory_DList(& $root, $text)
 {
 	$out = explode('|', ltrim($text), 2);
 	if (count($out) < 2) {
@@ -131,7 +131,7 @@ function & Factory_DList(& $root, $text)
 }
 
 // '|'-separated table
-function & Factory_Table(& $root, $text)
+function Factory_Table(& $root, $text)
 {
 	if (! preg_match('/^\|(.+)\|([hHfFcC]?)$/', $text, $out)) {
 		return Factory_Inline($text);
@@ -141,7 +141,7 @@ function & Factory_Table(& $root, $text)
 }
 
 // Comma-separated table
-function & Factory_YTable(& $root, $text)
+function Factory_YTable(& $root, $text)
 {
 	if ($text == ',') {
 		return Factory_Inline($text);
@@ -150,7 +150,7 @@ function & Factory_YTable(& $root, $text)
 	}
 }
 
-function & Factory_Div(& $root, $text)
+function Factory_Div(& $root, $text)
 {
 	$matches = array();
 
@@ -189,7 +189,7 @@ class Inline extends Element
 			$text : make_link($text));
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
 		$this->elements[] = $obj->elements[0];
 		return $this;
@@ -206,9 +206,9 @@ class Inline extends Element
 		return join(($line_break ? '<br />' . "\n" : "\n"), $this->elements);
 	}
 
-	function & toPara($class = '')
+	function toPara($class = '')
 	{
-		$obj = & new Paragraph('', $class);
+		$obj = new Paragraph('', $class);
 		$obj->insert($this);
 		return $obj;
 	}
@@ -261,10 +261,10 @@ class Heading extends Element
 		$this->level++; // h2,h3,h4
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
 		parent::insert($obj);
-		return $this->last = & $this;
+		return $this->last = $this;
 	}
 
 	function canContain(& $obj)
@@ -328,7 +328,7 @@ class ListContainer extends Element
 
 		parent::insert(new ListElement($this->level, $tag2));
 		if ($text != '')
-			$this->last = & $this->last->insert(Factory_Inline($text));
+			$this->last = $this->last->insert(Factory_Inline($text));
 	}
 
 	function canContain(& $obj)
@@ -354,10 +354,10 @@ class ListContainer extends Element
 		$this->style = sprintf($_list_pad_str, $this->level, $margin, $margin);
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
 		if (! is_a($obj, get_class($this)))
-			return $this->last = & $this->last->insert($obj);
+			return $this->last = $this->last->insert($obj);
 
 		// Break if no elements found (BugTrack/524)
 		if (count($obj->elements) == 1 && empty($obj->elements[0]->elements))
@@ -426,9 +426,9 @@ class DList extends ListContainer
 	function DList($out)
 	{
 		parent::ListContainer('dl', 'dt', ':', $out[0]);
-		$this->last = & Element::insert(new ListElement($this->level, 'dd'));
+		$this->last = Element::insert(new ListElement($this->level, 'dd'));
 		if ($out[1] != '')
-			$this->last = & $this->last->insert(Factory_Inline($out[1]));
+			$this->last = $this->last->insert(Factory_Inline($out[1]));
 	}
 }
 
@@ -449,9 +449,9 @@ class BQuote extends Element
 		if ($head == '<') { // Blockquote close
 			$level       = $this->level;
 			$this->level = 0;
-			$this->last  = & $this->end($root, $level);
+			$this->last  = $this->end($root, $level);
 			if ($text != '')
-				$this->last = & $this->last->insert(Factory_Inline($text));
+				$this->last = $this->last->insert(Factory_Inline($text));
 		} else {
 			$this->insert(Factory_Inline($text));
 		}
@@ -462,16 +462,16 @@ class BQuote extends Element
 		return (! is_a($obj, get_class($this)) || $obj->level >= $this->level);
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
 		// BugTrack/521, BugTrack/545
 		if (is_a($obj, 'inline'))
 			return parent::insert($obj->toPara(' class="quotation"'));
 
 		if (is_a($obj, 'BQuote') && $obj->level == $this->level && count($obj->elements)) {
-			$obj = & $obj->elements[0];
+			$obj = $obj->elements[0];
 			if (is_a($this->last, 'Paragraph') && count($obj->elements))
-				$obj = & $obj->elements[0];
+				$obj = $obj->elements[0];
 		}
 		return parent::insert($obj);
 	}
@@ -481,14 +481,14 @@ class BQuote extends Element
 		return $this->wrap(parent::toString(), 'blockquote');
 	}
 
-	function & end(& $root, $level)
+	function end(& $root, $level)
 	{
-		$parent = & $root->last;
+		$parent = $root->last;
 
 		while (is_object($parent)) {
 			if (is_a($parent, 'BQuote') && $parent->level == $level)
 				return $parent->parent;
-			$parent = & $parent->parent;
+			$parent = $parent->parent;
 		}
 		return $this;
 	}
@@ -534,11 +534,11 @@ class TableCell extends Element
 
 		if ($text != '' && $text{0} == '#') {
 			// Try using Div class for this $text
-			$obj = & Factory_Div($this, $text);
+			$obj = Factory_Div($this, $text);
 			if (is_a($obj, 'Paragraph'))
-				$obj = & $obj->elements[0];
+				$obj = $obj->elements[0];
 		} else {
-			$obj = & Factory_Inline($text);
+			$obj = Factory_Inline($text);
 		}
 
 		$this->insert($obj);
@@ -589,7 +589,7 @@ class Table extends Element
 		$is_template = ($this->type == 'c');
 		$row = array();
 		foreach ($cells as $cell)
-			$row[] = & new TableCell($cell, $is_template);
+			$row[] = new TableCell($cell, $is_template);
 		$this->elements[] = $row;
 	}
 
@@ -598,7 +598,7 @@ class Table extends Element
 		return is_a($obj, 'Table') && ($obj->col == $this->col);
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
 		$this->elements[] = $obj->elements[0];
 		$this->types[]    = $obj->type;
@@ -613,7 +613,7 @@ class Table extends Element
 		for ($ncol = 0; $ncol < $this->col; $ncol++) {
 			$rowspan = 1;
 			foreach (array_reverse(array_keys($this->elements)) as $nrow) {
-				$row = & $this->elements[$nrow];
+				$row = $this->elements[$nrow];
 				if ($row[$ncol]->rowspan == 0) {
 					++$rowspan;
 					continue;
@@ -629,9 +629,9 @@ class Table extends Element
 		// Set colspan and style
 		$stylerow = NULL;
 		foreach (array_keys($this->elements) as $nrow) {
-			$row = & $this->elements[$nrow];
+			$row = $this->elements[$nrow];
 			if ($this->types[$nrow] == 'c')
-				$stylerow = & $row;
+				$stylerow = $row;
 			$colspan = 1;
 			foreach (array_keys($row) as $ncol) {
 				if ($row[$ncol]->colspan == 0) {
@@ -657,7 +657,7 @@ class Table extends Element
 			foreach (array_keys($this->elements) as $nrow) {
 				if ($this->types[$nrow] != $type)
 					continue;
-				$row        = & $this->elements[$nrow];
+				$row        = $this->elements[$nrow];
 				$row_string = '';
 				foreach (array_keys($row) as $ncol)
 					$row_string .= $row[$ncol]->toString();
@@ -718,7 +718,7 @@ class YTable extends Element
 		return is_a($obj, 'YTable') && ($obj->col == $this->col);
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
 		$this->elements[] = $obj->elements[0];
 		return $this;
@@ -752,7 +752,7 @@ class Pre extends Element
 		return is_a($obj, 'Pre');
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
 		$this->elements[] = $obj->elements[0];
 		return $this;
@@ -832,14 +832,14 @@ class Body extends Element
 	function Body($id)
 	{
 		$this->id            = $id;
-		$this->contents      = & new Element();
-		$this->contents_last = & $this->contents;
+		$this->contents      = new Element();
+		$this->contents_last = $this->contents;
 		parent::Element();
 	}
 
 	function parse(& $lines)
 	{
-		$this->last = & $this;
+		$this->last = $this;
 		$matches = array();
 
 		while (! empty($lines)) {
@@ -850,7 +850,7 @@ class Body extends Element
 
 			if (preg_match('/^(LEFT|CENTER|RIGHT):(.*)$/', $line, $matches)) {
 				// <div style="text-align:...">
-				$this->last = & $this->last->add(new Align(strtolower($matches[1])));
+				$this->last = $this->last->add(new Align(strtolower($matches[1])));
 				if ($matches[2] == '') continue;
 				$line = $matches[2];
 			}
@@ -859,7 +859,7 @@ class Body extends Element
 
 			// Empty
 			if ($line == '') {
-				$this->last = & $this;
+				$this->last = $this;
 				continue;
 			}
 
@@ -896,7 +896,7 @@ class Body extends Element
 
 			// Pre
 			if ($head == ' ' || $head == "\t") {
-				$this->last = & $this->last->add(new Pre($this, $line));
+				$this->last = $this->last->add(new Pre($this, $line));
 				continue;
 			}
 
@@ -907,19 +907,19 @@ class Body extends Element
 			// Other Character
 			if (isset($this->classes[$head])) {
 				$classname  = $this->classes[$head];
-				$this->last = & $this->last->add(new $classname($this, $line));
+				$this->last = $this->last->add(new $classname($this, $line));
 				continue;
 			}
 
 			// Other Character
 			if (isset($this->factories[$head])) {
 				$factoryname = 'Factory_' . $this->factories[$head];
-				$this->last  = & $this->last->add($factoryname($this, $line));
+				$this->last  = $this->last->add($factoryname($this, $line));
 				continue;
 			}
 
 			// Default
-			$this->last = & $this->last->add(Factory_Inline($line));
+			$this->last = $this->last->add(Factory_Inline($line));
 		}
 	}
 
@@ -935,7 +935,7 @@ class Body extends Element
 		$id = make_heading($text, FALSE); // Cut fixed-anchor from $text
 		if ($id == '') {
 			// Not specified
-			$id     = & $autoid;
+			$id     = $autoid;
 			$anchor = '';
 		} else {
 			$anchor = ' &aname(' . $id . ',super,full){' . $_symbol_anchor . '};';
@@ -944,15 +944,15 @@ class Body extends Element
 		$text = ' ' . $text;
 
 		// Add 'page contents' link to its heading
-		$this->contents_last = & $this->contents_last->add(new Contents_UList($text, $level, $id));
+		$this->contents_last = $this->contents_last->add(new Contents_UList($text, $level, $id));
 
 		// Add heding
 		return array($text . $anchor, $this->count > 1 ? "\n" . $top : '', $autoid);
 	}
 
-	function & insert(& $obj)
+	function insert(& $obj)
 	{
-		if (is_a($obj, 'Inline')) $obj = & $obj->toPara();
+		if (is_a($obj, 'Inline')) $obj = $obj->toPara();
 		return parent::insert($obj);
 	}
 
@@ -964,7 +964,7 @@ class Body extends Element
 
 		// #contents
 		$text = preg_replace_callback('/<#_contents_>/',
-			array(& $this, 'replace_contents'), $text);
+			array($this, 'replace_contents'), $text);
 
 		return $text . "\n";
 	}
